@@ -1,14 +1,9 @@
-import copy
 from functools import reduce
 from pyidp3.idp_py_syntax import parse_formula
 from pyidp3.idpobjects import *
 
 IDP_LOCATION = "~/idp/usr/local/bin/idp"  # The path to your idp installation.
 
-# Old, relative imports
-# from .idp_py_syntax import parse_formula
-# from .idpobjects import *
-
 
 class Block(object):
     """
@@ -674,7 +669,7 @@ class IDP(object):
         The __str__ magic method will convert the Theory, Structure and
         Vocabulary Blocks into IDP format.
         By adding a Main afterwards (and optionally a Term), we can create a
-        full IDP script. See the generateScript method for an example.
+        full IDP script. See the modelexpand_script method for an example.
 
         :returns: The 3 main blocks string-ified in IDP format.
         :rtype: str
@@ -683,7 +678,7 @@ class IDP(object):
         return "\n".join([bl.show(list(self.idpobjects.values())) for bl 
                           in self.blocks])
 
-    def generateScript(self):
+    def modelexpand_script(self):
         """
         Generates the IDP-ready script for basic modelgeneration.
         Works by adding a Main block to all the other blocks.
@@ -700,7 +695,7 @@ class IDP(object):
         return str(self) + "\n" + IDP.mainblock_start + \
             self.generate_options() + mainblock_expand_models + "}\n"
 
-    def minimizeScript(self, termblock):
+    def minimize_script(self, termblock):
         """
         Generates the script for basic minimization of a term.
         Works by adding a Term and a Main block to the other blocks.
@@ -835,15 +830,15 @@ class IDP(object):
         import os
         if __debug__:
             print("SENT TO IDP:")
-            print(self.generateScript())
+            print(self.modelexpand_script())
             print("END OF IDP INPUT")
             f = open('IDPscript.txt', 'w')
-            f.write(self.generateScript())
+            f.write(self.modelexpand_script())
             f.close()
             print("SENT TO IDP:")
         idp = Popen(self.executable, stdin=PIPE, stdout=PIPE, stderr=PIPE)
         # input is the generated idp file
-        out, err = idp.communicate(input=(self.generateScript()).encode())
+        out, err = idp.communicate(input=(self.modelexpand_script()).encode())
         out = out.decode()
         err = err.decode()  # python3: communicate only works with byte objects
         if err and __debug__:
@@ -890,7 +885,7 @@ class IDP(object):
         import os
 
         termblock = Term(term)  # create a termblock, to minimize term
-        script = self.minimizeScript(termblock)
+        script = self.minimize_script(termblock)
 
         if __debug__:
             # write it to a file if debug
@@ -955,10 +950,6 @@ class IDP(object):
 
     mainblock_start = "procedure main(){\n"
 
-    # a constant string to define a mainblock to search for a model
-
-    # a constant string to define a mainblock to search for minimization
-
     # a constant string to define a mainblock which checks SAT
     mainblock_check_sat = """
     print(sat(T,S))
